@@ -14,12 +14,12 @@ from unittest import mock
 
 import black
 import executing
-import inline_snapshot._external
 import pytest
-from inline_snapshot import _inline_snapshot
+
+import inline_snapshot._external
 from inline_snapshot._change import apply_all
+from inline_snapshot._flags import Flags
 from inline_snapshot._format import format_code
-from inline_snapshot._inline_snapshot import Flags
 from inline_snapshot._rewrite_code import ChangeRecorder
 from inline_snapshot._types import Category
 from inline_snapshot.testing._example import snapshot_env
@@ -101,45 +101,46 @@ from inline_snapshot import outsource
             print("input:")
             print(textwrap.indent(source, " |", lambda line: True).rstrip())
 
-            with snapshot_env():
-                with ChangeRecorder().activate() as recorder:
-                    _inline_snapshot._update_flags = flags
-                    inline_snapshot._external.storage = (
-                        inline_snapshot._external.DiscStorage(tmp_path / ".storage")
-                    )
+            with snapshot_env() as state:
+                recorder = ChangeRecorder()
+                state.update_flags = flags
+                state.storage = inline_snapshot._external.DiscStorage(
+                    tmp_path / ".storage"
+                )
 
-                    error = False
+                error = False
 
-                    try:
-                        exec(compile(filename.read_text("utf-8"), filename, "exec"), {})
-                    except AssertionError:
-                        traceback.print_exc()
-                        error = True
-                    finally:
-                        _inline_snapshot._active = False
+                try:
+                    exec(compile(filename.read_text("utf-8"), filename, "exec"), {})
+                except AssertionError:
+                    traceback.print_exc()
+                    error = True
+                finally:
+                    state.active = False
 
-                    number_snapshots = len(_inline_snapshot.snapshots)
+                number_snapshots = len(state.snapshots)
 
-                    changes = []
-                    for snapshot in _inline_snapshot.snapshots.values():
-                        changes += snapshot._changes()
+                changes = []
+                for snapshot in state.snapshots.values():
+                    changes += snapshot._changes()
 
-                    snapshot_flags = {change.flag for change in changes}
+                snapshot_flags = {change.flag for change in changes}
 
-                    apply_all(
-                        [
-                            change
-                            for change in changes
-                            if change.flag in _inline_snapshot._update_flags.to_set()
-                        ]
-                    )
+                apply_all(
+                    [
+                        change
+                        for change in changes
+                        if change.flag in state.update_flags.to_set()
+                    ],
+                    recorder,
+                )
 
-                    recorder.fix_all()
+                recorder.fix_all()
 
             source = filename.read_text("utf-8")[len(prefix) :]
             print("reported_flags:", snapshot_flags)
             print(
-                f"run: pytest" + f' --inline-snapshot={",".join(flags.to_set())}'
+                f'run: pytest --inline-snapshot={",".join(flags.to_set())}'
                 if flags
                 else ""
             )
@@ -235,6 +236,22 @@ class RunResult:
         result = re.sub(r"\d+\.\d+s", "<time>", result)
         return result
 
+    @property
+    def stderr(self):
+        original = self._result.stderr.lines
+        lines = [
+            line
+            for line in original
+            if not any(
+                s in line
+                for s in [
+                    'No entry for terminal type "unknown"',
+                    "using dumb terminal settings.",
+                ]
+            )
+        ]
+        return pytest.LineMatcher(lines)
+
     def errorLines(self):
         result = self._join_lines(
             [line for line in self.stdout.lines if line and line[:2] in ("> ", "E ")]
