@@ -7,9 +7,9 @@ from dataclasses import dataclass
 from typing import Union
 
 import pytest
-from inline_snapshot import _inline_snapshot
+
 from inline_snapshot import snapshot
-from inline_snapshot._inline_snapshot import Flags
+from inline_snapshot._flags import Flags
 from inline_snapshot.testing import Example
 from inline_snapshot.testing._example import snapshot_env
 
@@ -23,8 +23,8 @@ def test_snapshot_eq():
 
 @pytest.mark.no_rewriting
 def test_disabled():
-    with snapshot_env():
-        _inline_snapshot._active = False
+    with snapshot_env() as state:
+        state.active = False
         with pytest.raises(AssertionError) as excinfo:
             assert 2 == snapshot()
 
@@ -862,7 +862,7 @@ def test_starred_warns_list():
             [
                 Warning(
                     message="InlineSnapshotSyntaxWarning: star-expressions are not supported inside snapshots",
-                    line=4,
+                    line=5,
                 )
             ]
         ),
@@ -872,7 +872,8 @@ def test_starred_warns_list():
             """
 from inline_snapshot import snapshot
 
-assert [5] == snapshot([*[5]])
+def test():
+    assert [5] == snapshot([*[5]])
 """
         ).run_inline(["--inline-snapshot=fix"])
 
@@ -883,7 +884,7 @@ def test_starred_warns_dict():
             [
                 Warning(
                     message="InlineSnapshotSyntaxWarning: star-expressions are not supported inside snapshots",
-                    line=4,
+                    line=5,
                 )
             ]
         ),
@@ -893,7 +894,8 @@ def test_starred_warns_dict():
             """
 from inline_snapshot import snapshot
 
-assert {1:3} == snapshot({**{1:3}})
+def test():
+    assert {1:3} == snapshot({**{1:3}})
 """
         ).run_inline(["--inline-snapshot=fix"])
 
@@ -940,3 +942,29 @@ def test_Is():
             }
         ),
     )
+
+
+def test_create_elipsis():
+    Example(
+        """\
+from inline_snapshot import snapshot
+
+def test_a():
+    assert 1+1==snapshot(...)
+    assert [1,2,8] == snapshot([1,2,...])
+        """
+    ).run_inline(
+        ["--inline-snapshot=create"],
+        changed_files=snapshot(
+            {
+                "test_something.py": """\
+from inline_snapshot import snapshot
+
+def test_a():
+    assert 1+1==snapshot(2)
+    assert [1,2,8] == snapshot([1,2,8])
+        \
+"""
+            }
+        ),
+    )
