@@ -1,9 +1,9 @@
 import pytest
+from executing import is_pytest_compatible
+
 from inline_snapshot import snapshot
 from inline_snapshot.testing import Example
 
-from .utils import pytest_compatible
-
 
 def test_help_message(testdir):
     result = testdir.runpytest_subprocess("--help")
@@ -32,7 +32,7 @@ You can also use --inline-snapshot=review to approve the changes interactively
 
     result = project.run("--inline-snapshot=create")
 
-    result.assert_outcomes(passed=1)
+    result.assert_outcomes(passed=1, errors=1)
 
     assert result.report == snapshot(
         """\
@@ -124,7 +124,7 @@ Info: one snapshot changed its representation (--inline-snapshot=update)
 You can also use --inline-snapshot=review to approve the changes interactively
 """
         )
-        if pytest_compatible
+        if is_pytest_compatible()
         else snapshot("")
     )
 
@@ -222,7 +222,7 @@ Info: one snapshot changed its representation (--inline-snapshot=update)
 You can also use --inline-snapshot=review to approve the changes interactively
 """
         )
-        if pytest_compatible
+        if is_pytest_compatible()
         else snapshot(
             """\
 Error: one snapshot has incorrect values (--inline-snapshot=fix)
@@ -698,8 +698,48 @@ UsageError:
 inline-snapshot uses `copy.deepcopy` to copy objects,
 but the copied object is not equal to the original one:
 
-original: Thing()
-copied:   Thing()
+value = Thing()
+copied_value = copy.deepcopy(value)
+assert value == copied_value
+
+Please fix the way your object is copied or your __eq__ implementation.
+"""
+        ),
+    )
+
+
+def test_equal_check_2():
+
+    Example(
+        {
+            "test_a.py": """
+from inline_snapshot import snapshot
+
+class A:
+    def __eq__(self,other):
+        if isinstance(other,A):
+            return False
+        return NotImplemented
+
+    def __repr__(self):
+        return "A()"
+
+def test_a():
+    assert A() == snapshot(A())
+    """,
+        }
+    ).run_inline(
+        ["--inline-snapshot=create"],
+        changed_files=snapshot({}),
+        raises=snapshot(
+            """\
+UsageError:
+inline-snapshot uses `copy.deepcopy` to copy objects,
+but the copied object is not equal to the original one:
+
+value = A()
+copied_value = copy.deepcopy(value)
+assert value == copied_value
 
 Please fix the way your object is copied or your __eq__ implementation.
 """
@@ -718,12 +758,7 @@ def test_a():
         ["--inline-snapshot=creaigflen"],
         report=snapshot(""),
         returncode=snapshot(4),
-        stderr=snapshot(
-            """\
-ERROR: --inline-snapshot=creaigflen is a unknown flag
-
-"""
-        ),
+        stderr=snapshot("ERROR: --inline-snapshot=creaigflen is a unknown flag\n"),
     )
 
 
@@ -737,7 +772,7 @@ def test_storage_dir_config(project, tmp_path, storage_dir):
     project.pyproject(
         f"""
 [tool.inline-snapshot]
-storage-dir = "{storage_dir}"
+storage-dir = {str(storage_dir)!r}
 """
     )
 
@@ -751,7 +786,7 @@ def test_outsource():
     )
 
     result = project.run("--inline-snapshot=create")
-    assert result.ret == 0
+    assert result.ret == 1
     assert project.source == snapshot(
         """\
 from inline_snapshot import outsource, snapshot
@@ -763,7 +798,7 @@ def test_outsource():
 """
     )
 
-    project.run("--inline-snapshot=fix")
+    result = project.run("--inline-snapshot=fix")
     assert result.ret == 0
 
     assert project.storage(storage_dir) == snapshot(
